#!/bin/sh
# the next line restarts using tclsh \
	exec tclsh "$0" "$@"

source pack.ini

regsub ".*/" $SRC_DIR "" SRC_DIR_NAME

set TMP_DIR		/tmp

set TARGET		"[pwd]/$SRC_DIR_NAME.setup.sh"

set TGZ_FILE	"$SRC_DIR_NAME.tgz"

set VERSION		"1.0.1"

###################################################################

if { $argc == 0 } {
	set NULL /dev/null
} else {
	set NULL /dev/tty
}

if { ![file isdirectory $SRC_DIR ] } {
	puts $SRC_DIR: directory not found
	exit 1
}

file delete -force $TARGET

cd $SRC_DIR/..
exec find $SRC_DIR -name DEADJOE -exec rm -f \{\} \;	
exec make -s -C $SRC_DIR clean > /dev/null
exec tar -cvzhf $TGZ_FILE $SRC_DIR_NAME > $NULL

set fd [open $TARGET w]

set data \
{#!/bin/sh

:
:
}
append data \
":   Pack version $VERSION
:
:   Pack directory into an auto-extract, -build and -install executable
:
:
:
:
"
foreach var "SRC_DIR_NAME SRC_DIR TMP_DIR TGZ_FILE" {
	append data "$var='[subst $$var]'\n"
}

append data {
if [ "$1" = check ] ; then
	lcnt=`cat $0| wc -l`
	lcnt=`expr $lcnt - 1`
	head -n $lcnt $0 | md5sum
	tail -n 1 $0
	if [ -f $0.md5 ]; then
		cat $0.md5
	fi
	exit 0
fi

output=/dev/null

if [ "$1" != xterm -a "$1" != blind ] ; then
	tty=`ps j $$ | tail -n 1 | awk '{ print $5 }'`
	sid=`ps j $$ | tail -n 1 | awk '{ print $4 }'`
	xsid=`ps j -C X | tail -n 1 | awk '{ print $4 }'`

	echo $tty, $sid, $xsid > $output

	if [ $tty = '?' -o "$sid" = "$xsid" ] ; then

		echo xterm > $output

		if ! xterm -fg black -bg white -g 80x25 -font fixed -e "$0" xterm \
			> $output 2>&1 ; then
			(echo ; echo ) | "$0" blind
		fi
		exit 0
	fi
fi

if [ "$1" = "extract" ] ; then
	echo TGZ_FILE=\'$TGZ_FILE\'\; SRC_DIR=\'$SRC_DIR\'\; TMP_DIR=\'$TMP_DIR\'
else
	echo '(*) Extract files from ['$0'] to ['$TMP_DIR/$SRC_DIR_NAME']'
fi
uudecode "$0"			|| exit 1
cd $TMP_DIR				|| exit 1
tar -xzf "$TGZ_FILE"	|| exit 1
cd "$SRC_DIR_NAME"		|| exit 1
if [ "$1" = "extract" ] ; then
	exit 0
fi
echo '(*) Start installer ['$TMP_DIR/$SRC_DIR_NAME/setup']'
./setup $* || exit 1

if [ "$1" = xterm ] ; then
	echo
	echo "Press 'Enter' to continue..."
	read tmp
fi

exit 0

}
puts $fd $data
close $fd

exec uuencode $TGZ_FILE "$TMP_DIR/$TGZ_FILE" >> $TARGET
exec date >> $TARGET
set md5 [exec cat $TARGET | md5sum]
exec echo $md5 >> $TARGET

exec chmod 755 $TARGET
file delete -force $TGZ_FILE

puts "$SRC_DIR ==> $TARGET"


